summaryrefslogtreecommitdiff
path: root/src/body_layer.zig
diff options
context:
space:
mode:
Diffstat (limited to 'src/body_layer.zig')
-rw-r--r--src/body_layer.zig4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/body_layer.zig b/src/body_layer.zig
index 71529326..1f210220 100644
--- a/src/body_layer.zig
+++ b/src/body_layer.zig
@@ -460,8 +460,8 @@ pub fn renderBody(p: *Pardes, arena: std.mem.Allocator, pane: *Pane, r: Rect, id
}
// cursor: tracks the shell cursor until pinned by a click or a key
- // (the tag cursor above wins while the tag is focused)
- if (active and !pane.tag_edit) {
+ // (the tag's or a prompt's cursor wins while that is being typed into)
+ if (active and !pane.tag_edit and (pane.prompt == .none or pane.prompt == .del_side)) {
if (pane.body.mode != .tty) {
const cur = panes.Terminal.gridCursor(pane);
const goff = panes.Terminal.gridOffset(pane);